use bevy::{
    prelude::*,
    sprite::{MaterialMesh2dBundle, Mesh2dHandle},
};
use bevy_rapier2d::prelude::*;
const METER: f32 = 48.;

fn main() {
    App::new()
        .add_plugins(DefaultPlugins)
        .insert_resource(RapierConfiguration::new(METER * 2.5))
        .add_plugins(RapierPhysicsPlugin::<NoUserData>::pixels_per_meter(METER))
        .add_plugins(RapierDebugRenderPlugin::default())
        .add_systems(Startup, (scene::setup_scene, setup_cam, player::add_player))
        .add_systems(
            Update,
            (player::move_player, player::player_ground_collision),
        )
        .run()
}

fn setup_cam(mut commands: Commands) {
    commands.spawn(Camera2dBundle {
        transform: Transform::from_xyz(0., 4. * METER, 0.),
        ..default()
    });
}

mod player;
mod scene;
